@@ -4,7 +4,7 @@ CREATE TABLE meta
 	key   varchar(255) primary key,
 	value varchar(255)
 );
-INSERT INTO meta (key, value) VALUES ('version', '0.1.8');
+INSERT INTO meta (key, value) VALUES ('version', '0.2.3');
 
 CREATE TABLE messages
 (
@@ -14,7 +14,8 @@ CREATE TABLE messages
 	in_use_by   int,
 	body        text,
 	timestamp   int,
-	size        int
+	size        int,
+	deliver_at  int
 );
 
 -- Improves performance some bit:
@@ -22,4 +23,5 @@ CREATE INDEX id_index          ON messages ( message_id(8) );
 CREATE INDEX timestamp_index   ON messages ( timestamp );
 CREATE INDEX destination_index ON messages ( destination );
 CREATE INDEX in_use_by_index   ON messages ( in_use_by );
+CREATE INDEX deliver_at        ON messages ( deliver_at );
 
